@@ -1,9 +1,10 @@
 package Net::Twitter::Error;
 use Moose;
 
-use overload '""' => \&error;
+use overload '""' => \&error,,
+             'fallback' => 1;
 
-has twitter_error   => ( isa => 'HashRef', is => 'rw', predicate => 'has_twitter_error' );
+has twitter_error   => ( isa => 'HashRef|Object', is => 'rw', predicate => 'has_twitter_error' );
 has http_response   => ( isa => 'HTTP::Response', is => 'rw', required => 1, handles => [qw/code message/] );
 
 sub error {
