@@ -10,29 +10,15 @@ with map "Net::Twitter::Role::$_", qw/
     WrapError
 /;
 
-has arrayref_on_error => ( isa => 'Bool', is => 'rw', default => 0,
-                           trigger => sub { shift->_set_error_return_val } );
-has twittervision     => ( isa => 'Bool', is => 'rw', default => 0 );
-
-=begin comment
-
-# TODO: MOP is not picking up UNIVERSAL methods; waiting for a fix
-# For transparent legacy support, we need ->isa('Net::Twitter') to succeed
-around isa => sub {
-    my $orig = shift;
-    my $self = shift;
-
-    return 1 if $_[0] eq 'Net::Twitter';
-    return $self->$orig(@_);
-};
-
-=cut
-
-sub _set_error_return_val {
+my $set_error_return_val = sub {
     my $self = shift;
 
     $self->_error_return_val($self->arrayref_on_error ? [] : undef);
-}
+};
+
+has arrayref_on_error => ( isa => 'Bool', is => 'rw', default => 0,
+                           trigger => sub { shift->$set_error_return_val } );
+has twittervision     => ( isa => 'Bool', is => 'rw', default => 0 );
 
 # Legacy Net::Twitter does not make the call unless twittervision is true.
 # Bug or feature?
